@@ -39,6 +39,7 @@ from LbEnv.ProjectEnv.lookup import (
     listPlatforms,
     listVersions,
     NotFoundError,
+    forced_paths,
 )
 from LbEnv.ProjectEnv.version import (
     isValidVersion,
@@ -479,7 +480,8 @@ class LbRun(xenv.Script):
             )
         if self.opts.path_to_project:
             self.project = None
-            self.version = os.path.abspath(self.cmd.pop(0))
+            self.version = None
+            forced_paths[self.project] = os.path.abspath(self.cmd.pop(0))
         elif "/" in self.cmd[0]:
             self.project, self.version = self.cmd.pop(0).split("/")
             self.project = fixProjectCase(self.project)
@@ -803,7 +805,7 @@ class LbRun(xenv.Script):
         #        'from . import path'
         from LbEnv.ProjectEnv import path, SearchPathEntry
 
-        if self.project.lower() == "lhcbdirac":
+        if self.project and self.project.lower() == "lhcbdirac":
             self.log.error(
                 "lb-run LHCbDIRAC is no longer available, please use lb-dirac instead"
             )
@@ -857,7 +859,7 @@ class LbRun(xenv.Script):
 
         # special handling of external projects
         # (unless we only want to list)
-        if self.project.upper() in EXTERNAL_PROJECTS:
+        if self.project and self.project.upper() in EXTERNAL_PROJECTS:
             self.opts.ext.append(self.project)
             if self.allow_empty_version:  # no version specified
                 # for LCG the version DEFAULT_VERSION does not make sense
@@ -943,7 +945,7 @@ class LbRun(xenv.Script):
                 "set",
                 (
                     "{}_PROJECT_ROOT".format(p.upper()),
-                    os.path.dirname(os.path.dirname(d)),
+                    str(os.path.dirname(os.path.dirname(d))),
                 ),
             )
             for p, d in getProjectsDirs(
@@ -954,15 +956,16 @@ class LbRun(xenv.Script):
             ).items()
         )
         # ... and data packages
-        self.opts.actions.extend(
-            ("set", ("{}ROOT".format(p.rsplit("/", 1)[-1].upper()), str(d)))
-            for p, d in getPackagesDirs(
-                self.project,
-                self.version,
-                self.opts.platform,
-                allow_empty_version=self.allow_empty_version,
-            ).items()
+        data_packages = getPackagesDirs(
+            self.project,
+            self.version,
+            self.opts.platform,
+            allow_empty_version=self.allow_empty_version,
         )
+        for p, d in data_packages.items():
+            self.opts.actions.append(
+                ("set", ("{}ROOT".format(p.rsplit("/", 1)[-1].upper()), str(d)))
+            )
 
         # now we can expand project name and version if --path-to-project
         if self.opts.path_to_project:
@@ -996,6 +999,15 @@ class LbRun(xenv.Script):
                 p = self.project
             self.opts.actions.append(("loadXML", (p + ".xenv",)))
 
+        # make sure we load the data packages too
+        for p, d in data_packages.items():
+            xml_path = "{}/{}.xenv".format(d, p.replace("/", "_"))
+            if not os.path.exists(xml_path):
+                # fall back on the old conventional name
+                xml_path = xml_path[:-5] + "Environment.xml"
+            # FIXME: xenv has got problems with unicode filenames
+            self.opts.actions.append(("loadXML", (str(xml_path),)))
+
         # handle the extra data packages
         for pkg_name, pkg_vers in map(decodePkg, self.opts.use):
             xml_name = pkg_name.replace("/", "_") + ".xenv"
